@@ -192,42 +192,63 @@ def menus(context, _get_config=None):
     if config.get('dynamic', False) is True:
         config = _import_reload(_get_config('DJANGO_SETTINGS_MODULE')).SIMPLEUI_CONFIG
 
-    app_list = context.get('app_list')
-    for app in app_list:
-        _models = [
-            {
-                'name': m.get('name'),
-                'icon': get_icon(m.get('object_name'), unicode_to_str(m.get('name'))),
-                'url': m.get('admin_url'),
-                'addUrl': m.get('add_url'),
-                'breadcrumbs': [{
-                    'name': app.get('name'),
-                    'icon': get_icon(app.get('app_label'), app.get('name'))
-                }, {
-                    'name': m.get('name'),
-                    'icon': get_icon(m.get('object_name'), unicode_to_str(m.get('name')))
-                }]
-            }
-
-            for m in app.get('models')
-        ] if app.get('models') else []
-
-        module = {
-            'name': app.get('name'),
-            'icon': get_icon(app.get('app_label'), app.get('name')),
-            'models': _models
-        }
-        data.append(module)
+    # app_list = context.get('app_list')
+    # for app in app_list:
+    #     _models = [
+    #         {
+    #             'name': m.get('name'),
+    #             'icon': get_icon(m.get('object_name'), unicode_to_str(m.get('name'))),
+    #             'url': m.get('admin_url'),
+    #             'addUrl': m.get('add_url'),
+    #             'breadcrumbs': [{
+    #                 'name': app.get('name'),
+    #                 'icon': get_icon(app.get('app_label'), app.get('name'))
+    #             }, {
+    #                 'name': m.get('name'),
+    #                 'icon': get_icon(m.get('object_name'), unicode_to_str(m.get('name')))
+    #             }]
+    #         }
+    #
+    #         for m in app.get('models')
+    #     ] if app.get('models') else []
+    #
+    #     module = {
+    #         'name': app.get('name'),
+    #         'icon': get_icon(app.get('app_label'), app.get('name')),
+    #         'models': _models
+    #     }
+    #     data.append(module)
 
     # 如果有menu 就读取，没有就调用系统的
     key = 'system_keep'
     if config and 'menus' in config:
         if config.get(key, None):
             temp = config.get('menus')
+            groups_permissions = context.request.user.get_group_permissions()
+            print(groups_permissions)
             for i in temp:
+                # check level 1 menu
+                if 'codename' not in i \
+                        or (True in [(True if i['codename'] in g_p else False)
+                                     for g_p in groups_permissions]) == False:
+                    if not context.request.user.is_superuser:
+                        continue
                 # 处理面包屑
                 if 'models' in i:
+                    delete_models = list()
                     for k in i.get('models'):
+                        # check level 2 menu
+                        if 'codename' not in i \
+                            or 'codename' not in k \
+                            or (i['codename']+'.'+(k['codename']) not in groups_permissions \
+                                and i['codename']+'.view_'+(k['codename']) not in groups_permissions \
+                                and i['codename']+'.add_'+(k['codename']) not in groups_permissions \
+                                and i['codename']+'.change_'+(k['codename']) not in groups_permissions \
+                                and i['codename']+'.delete_'+(k['codename']) not in groups_permissions \
+                                and k['codename'] not in groups_permissions):
+                            if not context.request.user.is_superuser:
+                                delete_models.append(k)
+                                continue
                         k['breadcrumbs'] = [{
                             'name': i.get('name'),
                             'icon': i.get('icon')
@@ -235,11 +256,14 @@ def menus(context, _get_config=None):
                             'name': k.get('name'),
                             'icon': k.get('icon')
                         }]
+                    for del_m in delete_models:
+                        i['models'].remove(del_m)
                 else:
                     i['breadcrumbs'] = [{
                         'name': i.get('name'),
                         'icon': i.get('icon')
                     }]
+                # if len(i[models]) > 0:
                 data.append(i)
         else:
             data = config.get('menus')
@@ -252,6 +276,27 @@ def menus(context, _get_config=None):
                 continue
             _app['_weight'] = config.get('menu_display').index(_app['name'])
             display_data.append(_app)
+
+        # if config.get('menu_display') is not None:
+        #     display_data = list()
+        #     for _app in data:
+        #         if _app['name'] not in config.get('menu_display'):
+        #             continue
+        #         # check level 2
+        #         if _app.get('menu_display') is not None:
+        #             display_model = list()
+        #             for _app_m in _app['models']:
+        #                 if _app_m['name'] not in _app.get('menu_display'):
+        #                     continue
+        #                 _app_m['_weight'] = _app.get('menu_display').index(_app_m['name'])
+        #                 display_model.append(_app_m)
+        #         else:
+        #             display_model = _app['models']
+        #
+        #         _app['models'] = display_model
+        #         _app['_weight'] = config.get('menu_display').index(_app['name'])
+        #         display_data.append(_app)
+
         display_data.sort(key=lambda x: x['_weight'])
         data = display_data
 
@@ -342,39 +387,7 @@ def get_analysis_config():
 
 @register.simple_tag(takes_context=True)
 def load_analysis(context):
-    try:
-        if not get_analysis_config():
-            return ''
-
-        # 理论上值一天只上报一次
-        key = 'simpleui_' + time.strftime('%Y%m%d', time.localtime())
-
-        if key in context.request.session:
-            return ''
-
-        b64 = ""
-        j = {
-            "n": platform.node(),
-            "o": platform.platform(),
-            "p": platform.python_version(),
-            "d": django.get_version(),
-            "s": eanoui.get_version(),
-        }
-        if 'theme_name' in context.request.COOKIES:
-            j['t'] = context.request.COOKIES['theme_name']
-        else:
-            j['t'] = 'Default'
-
-        b64 = base64.b64encode(str(j).encode('utf-8'))
-
-        url = '//simpleui.88cto.com/analysis'
-        b64 = b64.decode('utf-8')
-        html = '<script async type="text/javascript" src="{}/{}"></script>'.format(url, b64);
-        context.request.session[key] = True
-
-        return mark_safe(html)
-    except:
-        return ''
+    pass
 
 
 @register.simple_tag(takes_context=True)
@@ -523,4 +536,3 @@ def get_previous_url(context):
 @register.simple_tag(takes_context=True)
 def get_verbose_name_plural(context):
     return context['cl'].model._meta.verbose_name_plural
-
